@@ -6,7 +6,7 @@ import os
 
 from webhelpers2.html.tags import HTML
 
-from .compiler import Compiler
+from .asset import Asset
 
 log = logging.getLogger(__name__)
 
@@ -38,29 +38,39 @@ def render_js_paths(theme):
     return ''.join(['<script>'] + lines + ['</script>'])
 
 
-class RequireJSCompiler(Compiler):
+class RequireJSAsset(Asset):
     """
-    Compile require.js javascript for theme. Assumes r.js is on $PATH.
+    Asset handler for javascript loaded by require.js.
+
+    Currently assumes r.js is on $PATH.
     """
+    extension = 'js'
 
-    name = 'js'
+    def __init__(self, url_path,
+                 require_config_path='/_pfe/require_config.js',
+                 require_path='/_pfe/require.js',
+                 require_base_url='/_pfe/'):
+        self.url_path = url_path
+        self.require_config_path = require_config_path
+        self.require_path = require_path
+        self.require_base_url = require_base_url
 
-    def compile(self, key, theme, entry_point, output_dir, minify=True):
-        main_config = self.theme.static_url_to_filesystem_path(
-            self.theme.require_config_path)
-        base_url = self.theme.static_url_to_filesystem_path(
-            self.theme.require_base_url)
+    def compile(self, key, theme, output_dir, minify=True):
+        main_config = theme.static_url_to_filesystem_path(
+            self.require_config_path)
+        base_url = theme.static_url_to_filesystem_path(
+            self.require_base_url)
 
         log.debug("base_url: %r", base_url)
         log.debug("main_config: %r", main_config)
 
         # Path to main module relative to baseUrl (can't be absolute)
-        main_js_file = self.theme.static_url_to_filesystem_path(entry_point)
+        main_js_file = theme.static_url_to_filesystem_path(self.url_path)
         main = os.path.relpath(main_js_file, base_url)
         main = os.path.splitext(main)[0]  # Strip .js
 
         almond_path = \
-            self.theme.static_url_to_filesystem_path('/_pfe/almond.js')
+            theme.static_url_to_filesystem_path('/_pfe/almond.js')
         almond_path = os.path.relpath(almond_path, base_url)
         almond_path = os.path.splitext(almond_path)[0]
 
@@ -79,7 +89,7 @@ class RequireJSCompiler(Compiler):
             cmd.append('optimize=none')
 
         # Add RequireJS paths for theme
-        for dir_ref, dir in self.theme.keyed_static_dirs:
+        for dir_ref, dir in theme.keyed_static_dirs:
             dir = os.path.join(dir, 'js')
             log.debug("path _%s -> %s", key, dir)
             cmd.append('paths.{}={}'.format(dir_ref, dir))
@@ -87,24 +97,24 @@ class RequireJSCompiler(Compiler):
         with self.tempfile() as (f, temp_name):
             cmd.append('out={0}'.format(temp_name))
             self.run_command(cmd)
-            file_path = self.write_from_file(key, temp_name, entry_point,
+            file_path = self.write_from_file(key, temp_name, self.url_path,
                                              output_dir)
 
         return file_path
 
-    def tag_development(self, url):
+    def tag_development(self, theme, url):
         """
         Return an HTML fragment to use a require.js entry point in development.
         """
         return ''.join([
             js_preamble,
-            HTML.script(src=self.theme.require_config_path),
-            render_js_paths(self.theme),
-            HTML.script(src=self.theme.require_path),
+            HTML.script(src=self.require_config_path),
+            render_js_paths(theme),
+            HTML.script(src=self.require_path),
             HTML.script(src=url),
         ])
 
-    def tag_production(self, url):
+    def tag_production(self, theme, url):
         """
         Return an HTML fragment to use a require.js entry point in production.
         """
