@@ -7,9 +7,10 @@ from unittest import TestCase
 from six import StringIO
 
 from .. import compile
-from ..assets.compiler import Compiler
-from ..assets.less import LessCompiler
-from ..assets.requirejs import RequireJSCompiler
+from ..assets.asset import Asset
+from ..assets.less import LessAsset
+from ..assets.requirejs import RequireJSAsset
+from ..assets.svg import SVGAsset
 
 from . import utils
 from .example import foo
@@ -41,63 +42,69 @@ class TestCompileCommand(TestCase):
         # XXX Try to assett hat this makes longer assets or something.
 
 
-class TestCompiler(TestCase):
+class TestAsset(TestCase):
     def setUp(self):
         self.theme = foo.FooTheme({})
         self.output_dir = os.path.join(utils.work_dir, 'compile-tests')
 
     def test_bad_shell(self):
-        compiler = Compiler(None)
+        asset = Asset(None)
         buf = StringIO()
         with patch('sys.stdout', buf):
             with self.assertRaises(subprocess.CalledProcessError):
                 argv = [
                     'false',
                 ]
-                compiler.run_command(argv)
+                asset.run_command(argv)
         # XXX Try to test that this actually prints the stdout output of a
         # failed comamnd.
 
     def test_less_compile(self):
-        compiler = LessCompiler(self.theme)
-        path = compiler.compile(key='main-less',
-                                theme=self.theme,
-                                entry_point='/_foo/css/main.less',
-                                output_dir=self.output_dir)
+        asset = LessAsset('/_foo/css/main.less')
+        path = asset.compile(key='main-less',
+                             theme=self.theme,
+                             output_dir=self.output_dir)
         f = open(path, 'rb')
         buf_minified = f.read()
         self.assertGreater(len(buf_minified), 0)
 
         # Test that minified version is smaller than non-minified.
-        compiler = LessCompiler(self.theme)
-        path = compiler.compile(key='main-less',
-                                theme=self.theme,
-                                entry_point='/_foo/css/main.less',
-                                output_dir=self.output_dir,
-                                minify=False)
+        asset = LessAsset('/_foo/css/main.less')
+        path = asset.compile(key='main-less',
+                             theme=self.theme,
+                             output_dir=self.output_dir,
+                             minify=False)
         f = open(path, 'rb')
         buf_unminified = f.read()
 
         self.assertLess(len(buf_minified), len(buf_unminified))
 
     def test_requirejs_compile(self):
-        compiler = RequireJSCompiler(self.theme)
-        path = compiler.compile(key='main-js',
-                                theme=self.theme,
-                                entry_point='/_foo/js/main.js',
-                                output_dir=self.output_dir)
+        asset = RequireJSAsset('/_foo/js/main.js')
+        path = asset.compile(key='main-js',
+                             theme=self.theme,
+                             output_dir=self.output_dir)
         f = open(path, 'rb')
         buf_minified = f.read()
         self.assertGreater(len(buf_minified), 0)
 
         # Test that minified version is smaller than non-minified.
-        compiler = RequireJSCompiler(self.theme)
-        path = compiler.compile(key='main-js',
-                                theme=self.theme,
-                                entry_point='/_foo/js/main.js',
-                                output_dir=self.output_dir,
-                                minify=False)
+        asset = RequireJSAsset('/_foo/js/main.js')
+        path = asset.compile(key='main-js',
+                             theme=self.theme,
+                             output_dir=self.output_dir,
+                             minify=False)
         f = open(path, 'rb')
         buf_unminified = f.read()
 
         self.assertLess(len(buf_minified), len(buf_unminified))
+
+    def test_svg_compile(self):
+        asset = SVGAsset('/_foo/images/logo.svg')
+        path = asset.compile(key='logo-svg',
+                             theme=self.theme,
+                             output_dir=self.output_dir)
+        f = open(path, 'r')
+        buf = f.read()
+        self.assertGreater(len(buf), 0)
+        self.assertIn('svg', buf)
