@@ -33,7 +33,7 @@ class TestFiles(TestCase):
         # Saving same file twice should work
         files.save_to_error_dir(settings, '2.png', f)
 
-    def test_check_and_save_image(self):
+    def test_check_and_save_image_bad(self):
         f = open(os.path.join(samples_dir, 'not-an-image.png'), 'rb')
         error_dir = os.path.join(utils.work_dir, 'errors')
         settings = {
@@ -41,3 +41,13 @@ class TestFiles(TestCase):
         }
         with self.assertRaises(IOError):
             files.check_and_save_image(settings, 'not-an-image', f)
+
+    def test_check_and_save_image_good(self):
+        f = open(os.path.join(samples_dir, 'smiley-jpeg-rgb.jpg'), 'rb')
+        originals_dir = os.path.join(utils.work_dir, 'originals')
+        settings = {
+            'pyramid_frontend.original_image_dir': originals_dir,
+        }
+        info = files.check_and_save_image(settings, 'smiley-jpeg-rgb', f)
+        self.assertEqual(info['ext'], 'jpg')
+        self.assertEqual(info['size'], (512, 512))
